@@ -280,10 +280,13 @@ class TN(TLTNetworkModel):
         R = np.random.rand(sub_g.number_of_nodes(), sub_g.number_of_nodes()) # no god node
         #S = beta*(S_0 + A + sparse.identity(A.shape[0])) + (1-beta)*R
         eta = 64.
-        S = eta*S_0 + A + self._rand*R
+        S = eta*S_0 + A #+ self._rand*R
         model = NMF(n_components=self._numb_topics, init='nndsvd',
                     random_state=self._seed, max_iter=300)
         W = model.fit_transform(S)
+        W_mean = np.mean(W)
+        R2 = np.random.rand(sub_g.number_of_nodes(), self._numb_topics)
+        W = W_mean*(self._homophily*W/W_mean + (1-self._homophily)*R2/np.mean(R2))
         #print('Doing nmf with random coeff ', self._rand, ' and homophily ', self._homophily)
         if not np.all(np.isfinite(W)):
             print('ATTENTION W contains infinites')
